@@ -4,7 +4,8 @@ use warnings;
 # Call a wasm function from Perl
 use Wasm::Wasmtime;
 
-my $module = Wasm::Wasmtime::Module->new( wat => q{
+my $store = Wasm::Wasmtime::Store->new;
+my $module = Wasm::Wasmtime::Module->new( $store, wat => q{
   (module
    (func (export "add") (param i32 i32) (result i32)
      local.get 0
@@ -13,6 +14,6 @@ my $module = Wasm::Wasmtime::Module->new( wat => q{
   )
 });
 
-my $instance = Wasm::Wasmtime::Instance->new($module);
+my $instance = Wasm::Wasmtime::Instance->new($module, $store);
 my $add = $instance->exports->add;
 print $add->call(1,2), "\n";  # 3
