@@ -2,12 +2,14 @@ use strict;
 use warnings;
 use Wasm::Wasmtime;
 
+my $store = Wasm::Wasmtime::Store->new;
 my $instance = Wasm::Wasmtime::Instance->new(
-  Wasm::Wasmtime::Module->new(wat => q{
+  Wasm::Wasmtime::Module->new($store, wat => q{
     (module
       (table (export "table") 1 funcref)
     )
   }),
+  $store,
 );
 
 my $table = $instance->exports->table;
